// app/actions/github.ts
'use server'

import { auth, currentUser } from '@clerk/nextjs/server'
import { Octokit } from '@octokit/rest'
import type { Organization } from '@octokit/webhooks-types'

export async function getGitHubOrgs() {
  const { userId } = await auth()

  if (!userId) {
    throw new Error('Unauthorized')
  }

  const user = await currentUser()
  const githubAccount = user?.externalAccounts.find(
    (account) => account.provider === 'github'
  )

  const token =
    githubAccount?.provider === 'github' ? githubAccount.externalId : null

  if (!token) {
    throw new Error('GitHub not connected')
  }

  const octokit = new Octokit({ auth: token })
  const { data } = await octokit.rest.orgs.listForAuthenticatedUser()

  return data.map((org: Organization) => ({
    id: org.id,
    name: org.login,
    login: org.login,
    avatarUrl: org.avatar_url
  }))
}
