'use client'

import { PageWrapper } from '@/components/foundation/page-wrapper'
import { Button } from '@workspace/ui/components/button'
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle
} from '@workspace/ui/components/card'
/**
 * BuyPrepaidService component allows users to buy prepaid services.
 * It checks if the user's balance is sufficient and redirects them to the home page if it is.
 *
 * @returns {JSX.Element} A JSX element that renders the buy prepaid service page.
 */
const BuyPrepaidService = () => {
  return (
    <PageWrapper
      header={{
        title: 'Buy Prepaid Service',
        subtitle: 'Choose a plan that fits your deployment needs'
      }}
    >
      <div className=" mx-auto px-4 py-16 md:py-18 w-full">
        <div className="mx-auto w-full min-w-fit">
          <div className="text-center mb-12">
            <h2 className="font-normal text-gray-400 tracking-tight sm:text-2xl text-foreground">
              Laconic
            </h2>
            <h1 className="text-3xl font-bold tracking-tight sm:text-4xl text-foreground">
              Webapp Deployment Plans
            </h1>
            <p className="mt-4 text-muted-foreground">
              Choose the perfect deployment plan for your needs. Scale your
              applications with confidence.
            </p>
          </div>

          <div className="grid gap-6 md:grid-cols-3 w-full">
            {/* Basic Plan */}
            <Card className="border border-gray-200">
              <CardHeader>
                <CardTitle>Basic</CardTitle>
                <CardDescription>
                  A simple deployment option for small projects
                </CardDescription>
                <div className="mt-4">
                  <span className="text-3xl font-bold">$5.00</span>
                  <span className="text-muted-foreground ml-1">/month</span>
                </div>
              </CardHeader>
              <CardContent>
                <p className="text-sm text-muted-foreground mb-6">
                  1 monthly webapp deployment
                </p>
              </CardContent>
              <CardFooter>
                <Button className="w-full" variant="outline" asChild>
                  <a
                    href="https://store.laconic.com/products/1-webapp-deployment"
                    target="_blank"
                    rel="noopener noreferrer"
                  >
                    Purchase plan
                  </a>
                </Button>
              </CardFooter>
            </Card>

            {/* Standard Plan */}
            <Card className="border-2 border-primary relative">
              <div className="absolute -top-3 left-0 right-0 mx-auto w-fit rounded-full bg-primary px-3 py-1 text-xs font-medium text-primary-foreground">
                Most popular
              </div>
              <CardHeader>
                <CardTitle>Standard</CardTitle>
                <CardDescription>
                  Perfect for growing projects and businesses
                </CardDescription>
                <div className="mt-4">
                  <span className="text-3xl font-bold">$50.00</span>
                  <span className="text-muted-foreground ml-1">/month</span>
                </div>
              </CardHeader>
              <CardContent>
                <p className="text-sm text-muted-foreground mb-6">
                  10 monthly webapp deployments
                </p>
              </CardContent>
              <CardFooter>
                <Button className="w-full" asChild>
                  <a
                    href="https://store.laconic.com/products/10-webapp-deployments"
                    target="_blank"
                    rel="noopener noreferrer"
                  >
                    Purchase plan
                  </a>
                </Button>
              </CardFooter>
            </Card>

            {/* Premium Plan */}
            <Card className="border border-gray-200">
              <CardHeader>
                <CardTitle>Premium</CardTitle>
                <CardDescription>
                  For enterprises with high-volume needs
                </CardDescription>
                <div className="mt-4">
                  <span className="text-3xl font-bold">$500.00</span>
                  <span className="text-muted-foreground ml-1">/month</span>
                </div>
              </CardHeader>
              <CardContent>
                <p className="text-sm text-muted-foreground mb-6">
                  100 monthly webapp deployments
                </p>
              </CardContent>
              <CardFooter>
                <Button className="w-full" variant="outline" asChild>
                  <a
                    href="https://store.laconic.com/products/100-webapp-deployments"
                    target="_blank"
                    rel="noopener noreferrer"
                  >
                    Purchase plan
                  </a>
                </Button>
              </CardFooter>
            </Card>
          </div>
        </div>
      </div>
    </PageWrapper>
  )
}

export default BuyPrepaidService
