import { Providers } from '@/components/providers'
import { ClerkProvider } from '@clerk/nextjs'
import '@workspace/ui/globals.css'
import type { Metadata } from 'next'
import { Inter } from 'next/font/google'
import { CheckBalanceWrapper } from '@/components/iframe/check-balance-iframe/CheckBalanceWrapper'
import { AutoSignInIFrameModal } from '@/components/iframe/auto-sign-in'

// Add root metadata with template pattern
export const metadata: Metadata = {
  title: {
    template: '%s | Laconic Deploy',
    default: 'Laconic Deploy - Cloud Deployment Platform'
  },
  description: 'Deploy your applications with Laconic',
  metadataBase: new URL('https://deploy-laconic.qwrk.app'),
  icons: {
    icon: '/favicon.ico'
  }
}

const inter = Inter({ subsets: ['latin'] })

export default function RootLayout({
  children
}: Readonly<{ children: React.ReactNode }>) {
  return (
    <ClerkProvider signInFallbackRedirectUrl="/home">
      <html lang="en" suppressHydrationWarning>
        <body className={`${inter.className} `} suppressHydrationWarning>
          <main>
            <Providers>{children}</Providers>
            <div style={{ display: 'none' }}>
              <AutoSignInIFrameModal />
            </div>    
            <CheckBalanceWrapper />
          </main>
        </body>
      </html>
    </ClerkProvider>
  )
}
