'use client'
import { useEffect, useState } from 'react'
import { PageWrapper } from '@/components/foundation'
import { Button } from '@workspace/ui/components/button'
import { Shapes } from 'lucide-react'
import Link from 'next/link'
import { useAuth, useUser } from '@clerk/nextjs'
import { LoadingOverlay } from '@/components/foundation/loading/loading-overlay'

export default function HomePage() {
  const [isLoading, setIsLoading] = useState<boolean>(true)
  const { isLoaded: isAuthLoaded, userId } = useAuth()
  const { isLoaded: isUserLoaded } = useUser()
  
  useEffect(() => {
    // Check authentication status
    if (isAuthLoaded && isUserLoaded) {
      setIsLoading(false)
    }
  }, [isAuthLoaded, isUserLoaded])

  const handleConnectWallet = () => {
    // Handle wallet connection
    console.log('Connect wallet clicked')
  }

  if (isLoading) {
    return <LoadingOverlay isLoading={true} />
  }

  return (
    <PageWrapper
      header={{
        title: 'Welcome to Laconic Deploy',
        actions: userId ? [{ label: 'Create Project', href: '/projects/create' }] : []
      }}
      layout="bento"
      className="pb-0"
    >
      <div className="md:col-span-3 min-h-[80vh] flex flex-col items-center justify-center">
        {userId ? (
          // User is authenticated
          <div className="flex flex-col items-center text-center max-w-2xl mx-auto">
            <div className="mb-6">
              <Shapes size={80} className="stroke-current" />
            </div>
            <h1 className="text-4xl font-bold mb-6">Welcome to Laconic Deploy</h1>
            <p className="text-xl text-muted-foreground mb-8">
              Deploy your applications quickly and securely on the decentralized web.
            </p>
            
            <div className="flex gap-4">
              <Button asChild size="lg">
                <Link href="/projects">View My Projects</Link>
              </Button>
              <Button asChild variant="outline" size="lg">
                <Link href="/documentation">Documentation</Link>
              </Button>
            </div>
          </div>
        ) : (
          // User is not authenticated
          <div className="flex flex-col items-center text-center max-w-2xl mx-auto">
            <div className="mb-6">
              <Shapes size={80} className="stroke-current" />
            </div>
            <h1 className="text-4xl font-bold mb-6">Decentralized Web Deployment</h1>
            <p className="text-xl text-muted-foreground mb-8">
              Deploy your applications securely and efficiently with Laconic's web3 deployment platform.
              Connect your wallet to get started.
            </p>
            
            <Button onClick={handleConnectWallet} size="lg" className="mb-4">
              Connect Wallet
            </Button>
            
            <p className="text-sm text-muted-foreground mt-4">
              Already have an account? <Link href="/sign-in" className="text-primary hover:underline">Sign in</Link>
            </p>
          </div>
        )}
      </div>
      
      {/* Removed the CheckBalanceIframe component that was causing errors */}
    </PageWrapper>
  )
}