'use client'
import { useEffect, useState } from 'react'
import { useGQLClient } from '@/context'

export function GQLTest() {
  const [testResponse, setTestResponse] = useState<string>('Testing connection...')
  const [error, setError] = useState<string | null>(null)
  const gqlClient = useGQLClient()

  useEffect(() => {
    async function testGQLConnection() {
      try {
        // Try a direct GraphQL query using fetch
        const response = await fetch('http://localhost:8000/graphql', {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
          credentials: 'include', // Important for sending cookies
          body: JSON.stringify({
            query: `
              {
                __schema {
                  queryType {
                    name
                  }
                }
              }
            `
          })
        })
        
        const data = await response.json()
        setTestResponse(JSON.stringify(data, null, 2))
        
        // Check server logs to see if our request arrived
        console.log('GraphQL test response:', data)
      } catch (err) {
        console.error('Error testing GraphQL connection:', err)
        setError(err instanceof Error ? err.message : String(err))
      }
    }

    testGQLConnection()
  }, [gqlClient])

  // Function to test direct connection
  const testDirectConnection = async () => {
    try {
      setTestResponse('Testing direct connection...')
      setError(null)
      
      const response = await fetch('http://localhost:8000/auth/session', {
        method: 'GET',
        credentials: 'include',
      })
      
      const data = await response.json()
      setTestResponse(JSON.stringify(data, null, 2))
    } catch (err) {
      console.error('Error testing direct connection:', err)
      setError(err instanceof Error ? err.message : String(err))
    }
  }

  return (
    <div className="p-4 border rounded-md shadow-sm">
      <h2 className="text-lg font-bold mb-2">GraphQL Connection Test</h2>
      
      <div className="mb-4">
        <button 
          onClick={testDirectConnection}
          className="px-4 py-2 bg-blue-500 text-white rounded"
        >
          Test Direct Connection
        </button>
      </div>
      
      {error ? (
        <div className="text-red-500">
          <p>Error connecting to GraphQL server:</p>
          <pre className="bg-gray-900 p-2 rounded overflow-auto max-h-48">{error}</pre>
          <p className="mt-2">
            Authentication error is expected without a valid session. The GQL server requires authentication.
          </p>
          <p>Check the server logs to see if the request was received.</p>
        </div>
      ) : (
        <pre className="bg-gray-900 p-2 rounded overflow-auto max-h-48">{testResponse}</pre>
      )}
    </div>
  )
}