import { intervalToDuration } from 'date-fns'
import React from 'react'
import type { FormatMilliSecondProps } from './types'

/**
 * A component that formats a given time in milliseconds into a human-readable format.
 *
 * @component
 * @param {FormatMilliSecondProps} props - The props for the FormatMilliSecond component.
 * @returns {React.ReactElement} A formatted time element.
 *
 * @example
 * ```tsx
 * <FormatMilliSecond time={3600000} />
 * ```
 */
export const FormatMilliSecond = ({
  time,
  ...props
}: FormatMilliSecondProps) => {
  const duration = intervalToDuration({ start: 0, end: time })

  return (
    <div {...props} className="text-sm text-elements-mid-em">
      {duration.days !== 0 && <span>{duration.days}d&nbsp;</span>}
      {duration.hours !== 0 && <span>{duration.hours}h&nbsp;</span>}
      {duration.minutes !== 0 && <span>{duration.minutes}m&nbsp;</span>}
      <span>{duration.seconds}s</span>
    </div>
  )
}
