import Link from 'next/link'
import React from 'react'
import type { LogoProps } from './types'

/**
 * A component that renders the Laconic logo with a link to the organization's page.
 *
 * @component
 * @param {LogoProps} props - The props for the Logo component.
 * @returns {React.ReactElement} A logo element.
 *
 * @example
 * ```tsx
 * <Logo orgSlug="my-organization" />
 * ```
 */
export const Logo = ({ orgSlug }: LogoProps) => {
  return (
    <Link
      href={`/${orgSlug || ''}`}
      className="flex items-center gap-3 px-0 lg:px-2"
    >
      <img src="/logo.svg" alt="Laconic Logo" />
    </Link>
  )
}
