import React, { forwardRef } from 'react'
import type { SearchBarProps } from './types'

/**
 * A search bar component with an icon input.
 *
 * @component
 * @param {SearchBarProps} props - The props for the SearchBar component.
 * @returns {React.ReactElement} A search bar element.
 *
 * @example
 * ```tsx
 * <SearchBar value="search term" onChange={(e) => console.log(e.target.value)} />
 * ```
 */
export const SearchBar = forwardRef<HTMLInputElement, SearchBarProps>(
  ({ value, onChange, placeholder = 'Search', ...props }, ref) => {
    return (
      <div className="relative flex w-full">
        <div className="absolute left-2 top-1/2 transform -translate-y-1/2 text-gray-400">
          {/* Search icon SVG */}
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="16"
            height="16"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            aria-hidden="true"
            role="img"
          >
            <circle cx="11" cy="11" r="8" />
            <line x1="21" y1="21" x2="16.65" y2="16.65" />
          </svg>
        </div>
        <input
          ref={ref}
          value={value}
          onChange={onChange}
          type="search"
          placeholder={placeholder}
          className="w-full pl-8 px-3 py-2 border rounded lg:w-[459px]"
          {...props}
        />
      </div>
    )
  }
)
