import React from 'react'
import { StepperNav } from '../vertical-stepper/VerticalStepper'
import type { StepperProps, StepperValue } from './types'

const COLOR_COMPLETED = '#059669'
const COLOR_ACTIVE = '#CFE6FC'
const COLOR_NOT_STARTED = '#F1F5F9'

/**
 * A stepper component that displays a series of steps with different states.
 *
 * @component
 * @param {StepperProps} props - The props for the Stepper component.
 * @returns {React.ReactElement} A stepper element.
 *
 * @example
 * ```tsx
 * <Stepper activeStep={1} stepperValues={[{ step: 1, route: '/step1', label: 'Step 1' }]} />
 * ```
 */
export const Stepper = ({ activeStep, stepperValues }: StepperProps) => {
  return (
    <StepperNav
      steps={stepperValues.map((stepperValue: StepperValue) => {
        return {
          stepContent: () => (
            <div
              className={`text-sm ${
                activeStep === stepperValue.step
                  ? 'text-black font-semibold dark:text-foreground'
                  : 'text-gray-600 dark:text-foreground-secondary'
              }`}
            >
              {stepperValue.label}
            </div>
          ),
          stepStatusCircleSize: 30,
          stepStateColor:
            activeStep > stepperValue.step
              ? COLOR_COMPLETED
              : activeStep === stepperValue.step
                ? COLOR_ACTIVE
                : COLOR_NOT_STARTED
        }
      })}
    />
  )
}
