/**
 * Describes a step in the stepper navigation.
 * @interface IStepDescription
 * @property {() => JSX.Element} stepContent - The content of the step.
 * @property {string} [stepStateColor] - The color representing the step's state.
 * @property {number} [stepStatusCircleSize] - The size of the status circle.
 * @property {() => void} [onClickHandler] - Handler for click events on the step.
 */
export interface IStepDescription {
  stepContent: () => JSX.Element
  stepStateColor?: string
  stepStatusCircleSize?: number
  onClickHandler?: () => void
}

/**
 * Props for the StepperNav component.
 * @interface IStepperNavProps
 * @property {IStepDescription[]} steps - The steps to display in the navigation.
 */
export interface IStepperNavProps {
  steps: IStepDescription[]
}

/**
 * Props for the Separator component.
 * @interface ISeparator
 * @property {string | number} [height] - The height of the separator.
 */
export interface ISeparator {
  height?: string | number
}

/**
 * Props for the Step component.
 * @interface IStep
 * @property {() => JSX.Element} stepContent - The content of the step.
 * @property {string} [statusColor] - The color of the status circle.
 * @property {number} [statusCircleSize] - The size of the status circle.
 * @property {() => void} [onClickHandler] - Handler for click events on the step.
 */
export interface IStep {
  stepContent: () => JSX.Element
  statusColor?: string
  statusCircleSize?: number
  onClickHandler?: () => void
}
