import { Button } from '@workspace/ui/components/button'
import { Globe } from 'lucide-react'

/**
 * Coming Soon overlay component
 * Displays a message indicating a feature is not yet available
 *
 * @param props.message - Optional custom message to display
 * @param props.routerAction - Optional router action to perform when the button is clicked
 */
interface ComingSoonOverlayProps {
  message?: string
  routerAction?: () => void
  buttonText?: string
}

export function ComingSoonOverlay({
  message = 'This feature will be available in the next release.',
  routerAction,
  buttonText = 'Get Notified'
}: ComingSoonOverlayProps) {
  return (
    <div className="fixed inset-0 z-50 flex flex-col items-center justify-center bg-background/35 backdrop-blur-sm">
      <div className="text-center space-y-4 max-w-md px-4 bg-background/80 p-8 rounded-lg shadow-lg">
        <Globe className="h-16 w-16 mx-auto text-primary" />
        <h1 className="text-4xl font-bold tracking-tight">Coming Soon</h1>
        <p className="text-lg text-muted-foreground">{message}</p>
        {routerAction && <Button onClick={routerAction}>{buttonText}</Button>}
      </div>
    </div>
  )
}
