# PageHeader Component

A flexible page header component that displays a title with an optional subtitle and action buttons.

## Features

- Title with optional subtitle (text or component)
- Support for primary and secondary actions
- Responsive design with mobile-optimized action menu
- Customizable styling

## Usage

```tsx
import { PageHeader } from 'path/to/components/foundation/page-header'

// Basic usage
<PageHeader 
  title="Page Title" 
  subtitle="Simple text subtitle"
/>

// With actions
<PageHeader 
  title="Page Title" 
  subtitle="Simple text subtitle"
  actions={[
    { label: 'Primary Action', isPrimary: true, onClick: () => {} },
    { label: 'Secondary Action', href: '/some-path' }
  ]}
/>

// With component as subtitle
<PageHeader 
  title="Page Title" 
  subtitle={<SearchInput onChange={handleSearch} />}
  actions={[...]}
/>
```

## Props

See [types.ts](./types.ts) for detailed type definitions.

| Prop | Type | Description |
|------|------|-------------|
| `title` | `string` | The main heading text |
| `subtitle` | `string \| ReactNode` | Text or component to display below the title |
| `actions` | `PageAction[]` | Array of action buttons/links |
| `className` | `string` | Additional CSS classes |

## Action Configuration

Each action in the `actions` array can have the following properties:

| Property | Type | Description |
|----------|------|-------------|
| `label` | `string` | Display text for the button/link |
| `variant` | `string` | Button style variant |
| `onClick` | `() => void` | Click handler (for button actions) |
| `href` | `string` | URL (for link actions) |
| `isPrimary` | `boolean` | Whether this is a primary action | 