// import type React from 'react'
// import type { WalletSessionIdProps } from './types'

// /**
//  * A component that displays the wallet session ID with a connection status indicator.
//  *
//  * @param {WalletSessionIdProps} props - The props for the component.
//  * @returns {React.ReactElement} A div element containing the wallet session ID.
//  */
// export const WalletSessionId: React.FC<WalletSessionIdProps> = ({
//   walletId,
//   className = '',
//   isConnected = true
// }) => {
//   // For demonstration, use provided wallet ID or a placeholder
//   const displayId = walletId || 'x123xxx'

//   return (
//     <div
//       className={`flex items-center gap-2 rounded-md bg-gray-100 px-2.5 py-0.5 ${className}`}
//     >
//       <div
//         className={`h-2 w-2 rounded-full ${isConnected ? 'bg-green-400' : 'bg-gray-400'}`}
//         title={isConnected ? 'Connected' : 'Disconnected'}
//       />
//       <span className="text-gray-700 text-xs font-semibold">{displayId}</span>
//     </div>
//   )
// }

'use client'
import { useState } from 'react'
import { useWallet } from '@/context/WalletContextProvider'
import { Button } from '@workspace/ui/components/button'
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger
} from '@workspace/ui/components/dropdown-menu'
import { cn } from '@workspace/ui/lib/utils'
import { ChevronDown, LogOut } from 'lucide-react'

export function WalletSessionBadge() {
  const { wallet, isConnected, connect, disconnect } = useWallet()
  const [showAuthModal, setShowAuthModal] = useState(false)
  
  const handleConnect = () => {
    // Instead of directly showing the modal, call the connect function
    // from WalletContext which should now use the iframe messaging
    connect()
  }

  // Format address for display
  const formatAddress = (address?: string) => {
    if (!address) return 'Connect Wallet'
    return `${address.substring(0, 6)}...${address.substring(address.length - 4)}`
  }

  return (
    <DropdownMenu>
      <DropdownMenuTrigger asChild>
        <Button
          variant="outline"
          className={cn(
            'flex items-center space-x-2 rounded-md border px-3 py-1.5 text-sm font-medium',
            'hover:bg-accent hover:text-accent-foreground',
            'dark:bg-accent/5 dark:hover:bg-accent/10'
          )}
        >
          <span className="relative flex h-2 w-2">
            <span
              className={cn(
                'absolute inline-flex h-full w-full animate-ping rounded-full opacity-75',
                isConnected ? 'bg-green-400' : 'bg-red-400'
              )}
            />

            <span
              className={cn(
                'relative inline-flex h-2 w-2 rounded-full',
                isConnected ? 'bg-green-500' : 'bg-red-500'
              )}
            />
          </span>
          <span>{isConnected && wallet?.address 
            ? formatAddress(wallet.address) 
            : 'Connect Wallet'}</span>
          <ChevronDown className="h-4 w-4" />
        </Button>
      </DropdownMenuTrigger>
      <DropdownMenuContent align="end">
        {isConnected ? (
          <DropdownMenuItem
            className="flex cursor-pointer items-center text-destructive focus:text-destructive"
            onClick={disconnect}
          >
            <LogOut className="mr-2 h-4 w-4" />
            <span>Disconnect</span>
          </DropdownMenuItem>
        ) : (
          <DropdownMenuItem
            className="flex cursor-pointer items-center"
            onClick={handleConnect}
          >
            <span>Connect Wallet</span>
          </DropdownMenuItem>
        )}
      </DropdownMenuContent>
    </DropdownMenu>
  )
}