// 'use client'
// import { useCallback, useEffect, useState } from 'react'
// // Commenting out these imports as they cause linter errors due to missing dependencies
// // In an actual implementation, these would be properly installed
// // import { generateNonce, SiweMessage } from 'siwe'
// // import axios from 'axios'

// // Define proper types to replace 'any'
// interface SiweMessageProps {
//   version: string
//   domain: string
//   uri: string
//   chainId: number
//   address: string
//   nonce: string
//   statement: string
// }

// interface ValidateRequestData {
//   message: string
//   signature: string
// }

// // Mock implementations to demonstrate functionality without dependencies
// // In a real project, use the actual dependencies
// const generateNonce = () => Math.random().toString(36).substring(2, 15)
// const SiweMessage = class {
//   constructor(props: SiweMessageProps) {
//     this.props = props
//   }
//   props: SiweMessageProps
//   prepareMessage() {
//     return JSON.stringify(this.props)
//   }
// }

// // Access environment variables from .env.local with fallbacks for safety
// // In a production environment, these would be properly configured
// const WALLET_IFRAME_URL =
//   process.env.NEXT_PUBLIC_WALLET_IFRAME_URL || 'https://wallet.example.com'

// // Mock axios implementation
// const axiosInstance = {
//   post: async (url: string, data: ValidateRequestData) => {
//     console.log('Mock API call to', url, 'with data', data)
//     return { data: { success: true } }
//   }
// }

// /**
//  * AutoSignInIFrameModal component that handles wallet authentication through an iframe.
//  * This component is responsible for:
//  * 1. Getting the wallet address
//  * 2. Creating a Sign-In With Ethereum message
//  * 3. Requesting signature from the wallet
//  * 4. Validating the signature with the backend
//  *
//  * @returns {JSX.Element} A modal with an iframe for wallet authentication
//  */
// export function AutoSignInIFrameModal() {
//   const [accountAddress, setAccountAddress] = useState<string>()

//   // Handle sign-in response from the wallet iframe
//   useEffect(() => {
//     const handleSignInResponse = async (event: MessageEvent) => {
//       if (event.origin !== WALLET_IFRAME_URL) return

//       if (event.data.type === 'SIGN_IN_RESPONSE') {
//         try {
//           const response = await axiosInstance.post('/auth/validate', {
//             message: event.data.data.message,
//             signature: event.data.data.signature
//           })

//           if (response.data.success === true) {
//             // In Next.js, we would use router.push instead
//             window.location.href = '/'
//           }
//         } catch (error) {
//           console.error('Error signing in:', error)
//         }
//       }
//     }

//     window.addEventListener('message', handleSignInResponse)

//     return () => {
//       window.removeEventListener('message', handleSignInResponse)
//     }
//   }, [])

//   // Initiate auto sign-in when account address is available
//   useEffect(() => {
//     const initiateAutoSignIn = async () => {
//       if (!accountAddress) return

//       const iframe = document.getElementById(
//         'walletAuthFrame'
//       ) as HTMLIFrameElement

//       if (!iframe.contentWindow) {
//         console.error('Iframe not found or not loaded')
//         return
//       }

//       const message = new SiweMessage({
//         version: '1',
//         domain: window.location.host,
//         uri: window.location.origin,
//         chainId: 1,
//         address: accountAddress,
//         nonce: generateNonce(),
//         statement: 'Sign in With Ethereum.'
//       }).prepareMessage()

//       iframe.contentWindow.postMessage(
//         {
//           type: 'AUTO_SIGN_IN',
//           chainId: '1',
//           message
//         },
//         WALLET_IFRAME_URL
//       )
//     }

//     initiateAutoSignIn()
//   }, [accountAddress])

//   // Listen for wallet accounts data
//   useEffect(() => {
//     const handleAccountsDataResponse = async (event: MessageEvent) => {
//       if (event.origin !== WALLET_IFRAME_URL) return

//       if (
//         event.data.type === 'WALLET_ACCOUNTS_DATA' &&
//         event.data.data?.length > 0
//       ) {
//         setAccountAddress(event.data.data[0].address)
//       }
//     }

//     window.addEventListener('message', handleAccountsDataResponse)

//     return () => {
//       window.removeEventListener('message', handleAccountsDataResponse)
//     }
//   }, [])

//   // Request wallet address when iframe is loaded
//   const getAddressFromWallet = useCallback(() => {
//     const iframe = document.getElementById(
//       'walletAuthFrame'
//     ) as HTMLIFrameElement

//     if (!iframe.contentWindow) {
//       console.error('Iframe not found or not loaded')
//       return
//     }

//     iframe.contentWindow.postMessage(
//       {
//         type: 'REQUEST_CREATE_OR_GET_ACCOUNTS',
//         chainId: '1'
//       },
//       WALLET_IFRAME_URL
//     )
//   }, [])

//   return (
//     <div className="fixed inset-0 z-50 flex items-center justify-center bg-black/50">
//       <div className="relative w-[90%] max-w-6xl h-[600px] max-h-[80vh] overflow-auto rounded-lg bg-white shadow-lg">
//         <iframe
//           onLoad={getAddressFromWallet}
//           id="walletAuthFrame"
//           src={`${WALLET_IFRAME_URL}/auto-sign-in`}
//           className="w-full h-full"
//           sandbox="allow-scripts allow-same-origin"
//           title="Wallet Authentication"
//         />
//       </div>
//     </div>
//   )
// }

// src/components/iframe/auto-sign-in/AutoSignInIFrameModal.tsx
'use client'
import { useCallback, useEffect, useState } from 'react'
import { generateNonce, SiweMessage } from 'siwe'
import axios from 'axios'

const axiosInstance = axios.create({
  baseURL: process.env.NEXT_PUBLIC_API_URL || 'http://localhost:8000',
  headers: {
    'Content-Type': 'application/json',
    'Access-Control-Allow-Origin': '*'
  },
  withCredentials: true
})

const WALLET_IFRAME_URL = process.env.NEXT_PUBLIC_WALLET_IFRAME_URL || 'http://localhost:4000'

interface AutoSignInProps {
  onAuthComplete?: (success: boolean) => void
  onClose?: () => void
}

export function AutoSignInIFrameModal({ onAuthComplete, onClose }: AutoSignInProps = {}) {
  const [accountAddress, setAccountAddress] = useState<string>()
  const [isVisible, setIsVisible] = useState(true)
  const [authStatus, setAuthStatus] = useState<'idle' | 'connecting' | 'signing' | 'success' | 'error'>('idle')

  // Handle sign-in response from the wallet iframe
  useEffect(() => {
    const handleSignInResponse = async (event: MessageEvent) => {
      if (event.origin !== WALLET_IFRAME_URL) return

      if (event.data.type === 'SIGN_IN_RESPONSE') {
        try {
          setAuthStatus('signing')
          console.log('🔐 Validating SIWE signature...')
          
          const response = await axiosInstance.post('/auth/validate', {
            message: event.data.data.message,
            signature: event.data.data.signature
          })

          if (response.data.success === true) {
            console.log('✅ SIWE authentication successful!')
            setAuthStatus('success')
            
            // Notify parent component instead of redirecting
            onAuthComplete?.(true)
            
            // Close modal after a brief delay
            setTimeout(() => {
              setIsVisible(false)
              onClose?.()
            }, 1000)
          } else {
            console.error('❌ SIWE authentication failed')
            setAuthStatus('error')
            onAuthComplete?.(false)
          }
        } catch (error) {
          console.error('❌ Error during SIWE validation:', error)
          setAuthStatus('error')
          onAuthComplete?.(false)
        }
      }
    }

    window.addEventListener('message', handleSignInResponse)
    return () => window.removeEventListener('message', handleSignInResponse)
  }, [onAuthComplete, onClose])

  // Listen for wallet accounts data
  useEffect(() => {
    const handleAccountsDataResponse = async (event: MessageEvent) => {
      if (event.origin !== WALLET_IFRAME_URL) return

      if (event.data.type === 'WALLET_ACCOUNTS_DATA' && event.data.data?.length > 0) {
        let address;
        
        // Handle multiple data formats
        if (Array.isArray(event.data.data)) {
          if (typeof event.data.data[0] === 'string') {
            address = event.data.data[0];
          } else if (event.data.data[0] && typeof event.data.data[0].address === 'string') {
            address = event.data.data[0].address;
          }
        }
        
        if (address) {
          console.log('📱 Got wallet address for SIWE:', address)
          setAccountAddress(address)
          setAuthStatus('connecting')
        }
      }
    }

    window.addEventListener('message', handleAccountsDataResponse)
    return () => window.removeEventListener('message', handleAccountsDataResponse)
  }, [])

  // Initiate auto sign-in when account address is available
  useEffect(() => {
    const initiateAutoSignIn = async () => {
      if (!accountAddress) return

      console.log('🔐 Starting SIWE authentication for:', accountAddress)

      const iframe = document.getElementById('walletAuthFrame') as HTMLIFrameElement

      if (!iframe?.contentWindow) {
        console.error('❌ walletAuthFrame iframe not found')
        setAuthStatus('error')
        return
      }

      const message = new SiweMessage({
        version: '1',
        domain: window.location.host,
        uri: window.location.origin,
        chainId: 1,
        address: accountAddress,
        nonce: generateNonce(),
        statement: 'Sign in With Ethereum.'
      }).prepareMessage()

      console.log('📝 SIWE message created, requesting signature...')

      iframe.contentWindow.postMessage(
        {
          type: 'AUTO_SIGN_IN',
          chainId: '1',
          message
        },
        WALLET_IFRAME_URL
      )
    }

    if (accountAddress && authStatus === 'connecting') {
      setTimeout(initiateAutoSignIn, 500)
    }
  }, [accountAddress, authStatus])

  // Request wallet address when iframe is loaded
  const getAddressFromWallet = useCallback(() => {
    const iframe = document.getElementById('walletAuthFrame') as HTMLIFrameElement

    if (!iframe?.contentWindow) {
      console.error('❌ Iframe not found or not loaded')
      return
    }

    console.log('📤 Requesting wallet address for SIWE...')
    setAuthStatus('idle')

    iframe.contentWindow.postMessage(
      {
        type: 'REQUEST_CREATE_OR_GET_ACCOUNTS',
        chainId: '1'
      },
      WALLET_IFRAME_URL
    )
  }, [])

  // Don't render if not visible
  if (!isVisible) return null

  return (
    <div className="fixed inset-0 z-50 flex items-center justify-center bg-black/50">
      <div className="relative w-[90%] max-w-6xl h-[600px] max-h-[80vh] overflow-auto rounded-lg bg-white shadow-lg">
        {/* Status indicator */}
        <div className="absolute top-4 left-4 z-10 bg-white/90 px-3 py-2 rounded-md shadow-sm">
          <div className="flex items-center space-x-2">
            {authStatus === 'idle' && (
              <>
                <div className="w-2 h-2 bg-gray-400 rounded-full"></div>
                <span className="text-sm text-gray-600">Initializing...</span>
              </>
            )}
            {authStatus === 'connecting' && (
              <>
                <div className="w-2 h-2 bg-blue-400 rounded-full animate-pulse"></div>
                <span className="text-sm text-blue-600">Connecting wallet...</span>
              </>
            )}
            {authStatus === 'signing' && (
              <>
                <div className="w-2 h-2 bg-yellow-400 rounded-full animate-pulse"></div>
                <span className="text-sm text-yellow-600">Signing message...</span>
              </>
            )}
            {authStatus === 'success' && (
              <>
                <div className="w-2 h-2 bg-green-400 rounded-full"></div>
                <span className="text-sm text-green-600">Authentication complete!</span>
              </>
            )}
            {authStatus === 'error' && (
              <>
                <div className="w-2 h-2 bg-red-400 rounded-full"></div>
                <span className="text-sm text-red-600">Authentication failed</span>
              </>
            )}
          </div>
        </div>

        {/* Close button */}
        {onClose && (
          <button
            onClick={() => {
              setIsVisible(false)
              onClose()
            }}
            className="absolute top-4 right-4 z-10 bg-white/90 hover:bg-white px-2 py-1 rounded-md shadow-sm text-gray-600 hover:text-gray-800"
          >
            ✕
          </button>
        )}

        <iframe
          onLoad={getAddressFromWallet}
          id="walletAuthFrame"
          src={`${WALLET_IFRAME_URL}/auto-sign-in`}
          className="w-full h-full"
          sandbox="allow-scripts allow-same-origin"
          title="Wallet Authentication"
        />
      </div>
    </div>
  )
}