// src/components/iframe/check-balance-iframe/CheckBalanceIframe.tsx
'use client'

import { useEffect, useState } from 'react'
import useCheckBalance from './useCheckBalance'

const CHECK_BALANCE_INTERVAL = 5000
const BALANCE_IFRAME_ID = 'balance-check-iframe' // Different ID to avoid conflicts

/**
 * CheckBalanceIframe component for balance checking only.
 * This is separate from wallet connection functionality.
 */
const CheckBalanceIframe = ({
  onBalanceChange,
  isPollingEnabled,
  amount
}: {
  onBalanceChange: (value: boolean | undefined) => void
  isPollingEnabled: boolean
  amount: string
}) => {
  const { isBalanceSufficient, checkBalance } = useCheckBalance(
    amount,
    BALANCE_IFRAME_ID
  )

  const [isLoaded, setIsLoaded] = useState(false)

  // Check balance when loaded or amount changes
  useEffect(() => {
    if (!isLoaded) return
    checkBalance()
  }, [checkBalance, isLoaded])

  // Set up polling if enabled
  useEffect(() => {
    if (!isPollingEnabled || !isLoaded || isBalanceSufficient) {
      return
    }

    const interval = setInterval(() => {
      checkBalance()
    }, CHECK_BALANCE_INTERVAL)

    return () => clearInterval(interval)
  }, [isBalanceSufficient, isPollingEnabled, checkBalance, isLoaded])

  // Notify parent of balance changes
  useEffect(() => {
    onBalanceChange(isBalanceSufficient)
  }, [isBalanceSufficient, onBalanceChange])

  return (
    <div style={{ display: 'none' }}>
      {/* This iframe is only for balance checking, not wallet connection */}
      <iframe
        title="Balance Checker"
        onLoad={() => setIsLoaded(true)}
        id={BALANCE_IFRAME_ID}
        src={process.env.NEXT_PUBLIC_WALLET_IFRAME_URL}
        width="1"
        height="1"
        sandbox="allow-scripts allow-same-origin"
        style={{
          position: 'absolute',
          left: '-9999px',
          opacity: 0,
          pointerEvents: 'none'
        }}
      />
    </div>
  )
}

export default CheckBalanceIframe