import React from 'react'

/**
 * Renders the navigation actions, including buttons for creating a new project and displaying notifications.
 *
 * @returns {React.ReactElement} A div element containing the navigation actions.
 */
export function NavigationActions() {
  // Mock functions - in actual implementation these would handle navigation and state
  const navigateToCreateProject = () => {
    console.log('Navigate to create project')
  }

  return (
    <div className="flex items-center gap-3">
      {/* Create Project Button */}
      <button
        type="button"
        className="inline-flex items-center justify-center rounded-md bg-gray-100 p-2 text-gray-700 hover:bg-gray-200"
        onClick={navigateToCreateProject}
        aria-label="Create new project"
      >
        {/* Plus icon SVG */}
        <svg
          xmlns="http://www.w3.org/2000/svg"
          width="16"
          height="16"
          viewBox="0 0 24 24"
          fill="none"
          stroke="currentColor"
          strokeWidth="2"
          strokeLinecap="round"
          strokeLinejoin="round"
          aria-hidden="true"
        >
          <line x1="12" y1="5" x2="12" y2="19" />
          <line x1="5" y1="12" x2="19" y2="12" />
        </svg>
      </button>

      {/* Notifications Button */}
      <button
        type="button"
        className="inline-flex items-center justify-center rounded-md p-2 text-gray-500 hover:bg-gray-100 hover:text-gray-700"
        aria-label="View notifications"
      >
        {/* Bell icon SVG */}
        <svg
          xmlns="http://www.w3.org/2000/svg"
          width="16"
          height="16"
          viewBox="0 0 24 24"
          fill="none"
          stroke="currentColor"
          strokeWidth="2"
          strokeLinecap="round"
          strokeLinejoin="round"
          aria-hidden="true"
        >
          <path d="M18 8A6 6 0 0 0 6 8c0 7-3 9-3 9h18s-3-2-3-9" />
          <path d="M13.73 21a2 2 0 0 1-3.46 0" />
        </svg>
      </button>
    </div>
  )
}
