import type React from 'react'
import type { WalletSessionIdProps } from './types'

/**
 * A component that displays the wallet session ID.
 *
 * @param {WalletSessionIdProps} props - The props for the component.
 * @returns {React.ReactElement} A div element containing the wallet session ID.
 */
export const WalletSessionId: React.FC<WalletSessionIdProps> = ({
  walletId,
  className = ''
}) => {
  // Mock data - in actual implementation these would come from a wallet context
  const isConnected = true
  const wallet = { id: walletId || 'x123xxx' }

  const displayId = wallet?.id || 'Wallet'

  return (
    <div
      className={`flex items-center gap-2 rounded-md bg-gray-100 px-2.5 py-0.5 ${className}`}
    >
      <div
        className={`h-2 w-2 rounded-full ${isConnected ? 'bg-green-400' : 'bg-gray-400'}`}
      />
      <span className="text-gray-700 text-xs font-semibold">{displayId}</span>
    </div>
  )
}
