'use client'

import { GitBranch, Settings, Box } from 'lucide-react'
import type { Step } from '@/components/onboarding/useOnboarding'

interface OnboardingSidebarProps {
  currentStep: Step
}

export function OnboardingSidebar({ currentStep }: OnboardingSidebarProps) {
  return (
    <div className="w-[280px] bg-zinc-950 p-8 relative overflow-hidden">
      {/* Laconic logo */}
      <div className="flex items-center mb-12">
        <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" className="mr-2">
          <path d="M12 16L4 8L12 0L20 8L12 16Z" fill="white"/>
        </svg>
        <span className="text-white text-xl font-bold">LACONIC</span>
      </div>
      
      {/* Steps */}
      <div className="space-y-10">
        {/* Connect step */}
        <div className="flex">
          <div className="mr-4">
            <div className={`w-10 h-10 rounded-lg ${currentStep === 'connect' ? 'bg-white' : 'bg-zinc-800'} flex items-center justify-center`}>
              <GitBranch className={`h-5 w-5 ${currentStep === 'connect' ? 'text-black' : 'text-zinc-400'}`} />
            </div>
            <div className="w-px h-16 bg-zinc-800 mx-auto mt-2"></div>
          </div>
          <div>
            <h3 className={`font-medium text-base ${currentStep === 'connect' ? 'text-white' : 'text-zinc-400'}`}>Connect</h3>
            <p className={`text-sm ${currentStep === 'connect' ? 'text-zinc-400' : 'text-zinc-500'}`}>Connect and import a GitHub repo</p>
          </div>
        </div>
        
        {/* Configure step */}
        <div className="flex">
          <div className="mr-4">
            <div className={`w-10 h-10 rounded-lg ${currentStep === 'configure' ? 'bg-white' : 'bg-zinc-800'} flex items-center justify-center`}>
              <Settings className={`h-5 w-5 ${currentStep === 'configure' ? 'text-black' : 'text-zinc-400'}`} />
            </div>
            <div className="w-px h-16 bg-zinc-800 mx-auto mt-2"></div>
          </div>
          <div>
            <h3 className={`font-medium text-base ${currentStep === 'configure' ? 'text-white' : 'text-zinc-400'}`}>Configure</h3>
            <p className={`text-sm ${currentStep === 'configure' ? 'text-zinc-400' : 'text-zinc-500'}`}>Define the deployment type</p>
          </div>
        </div>
        
        {/* Deploy step */}
        <div className="flex">
          <div className="mr-4">
            <div className={`w-10 h-10 rounded-lg ${currentStep === 'deploy' || currentStep === 'success' ? 'bg-white' : 'bg-zinc-800'} flex items-center justify-center`}>
              <Box className={`h-5 w-5 ${currentStep === 'deploy' || currentStep === 'success' ? 'text-black' : 'text-zinc-400'}`} />
            </div>
          </div>
          <div>
            <h3 className={`font-medium text-base ${currentStep === 'deploy' || currentStep === 'success' ? 'text-white' : 'text-zinc-400'}`}>Deploy</h3>
            <p className={`text-sm ${currentStep === 'deploy' || currentStep === 'success' ? 'text-zinc-400' : 'text-zinc-500'}`}>Review and confirm deployment</p>
          </div>
        </div>
      </div>
      
      {/* Background shape (decorative) */}
      <div className="absolute -bottom-32 -left-32 w-64 h-64 rounded-full bg-zinc-900 opacity-50"></div>
    </div>
  )
}