import type React from 'react'

/**
 * Props for the OnboardingContainer component
 * @interface OnboardingContainerProps
 * @property {React.ReactNode} children - The content to be rendered inside the container
 */
interface OnboardingContainerProps {
  children: React.ReactNode
}

/**
 * A container component that provides the layout structure for the onboarding flow
 *
 * @component
 * @example
 * ```tsx
 * <OnboardingContainer>
 *   <SidebarNav currentStep={currentStep} />
 *   <MainContent />
 * </OnboardingContainer>
 * ```
 *
 * @param {OnboardingContainerProps} props - Component props
 * @returns {JSX.Element} A container with consistent sizing and layout
 */
export function OnboardingContainer({ children }: OnboardingContainerProps) {
  return (
    <div className="min-h-screen w-full bg-background flex items-center justify-center p-8 overflow-hidden left-0 top-0 ">
      <div className="flex gap-6 w-full max-w-[1200px] min-h-[700px] h-full  z-10 overflow-hidden">
        {children}
      </div>
    </div>
  )
}
