import { Button } from '@workspace/ui/components/button'
import { cn } from '@workspace/ui/lib/utils'
import { Github } from 'lucide-react'

interface ConnectButtonProps {
  /**
   * Optional override for the icon
   */
  icon?: React.ReactNode
  /**
   * Optional label for the button
   */
  label?: string
}

/**
 * A specialized button for the Connect step based on Figma design
 * Used for connecting to services like GitHub
 *
 * Figma Design Reference:
 * @see https://www.figma.com/design/cfMOy1RJasIu3QyzAMBFxB/Laconic?node-id=498-3285&m=dev
 */
export function ConnectButton({
  // className,
  icon = <Github />,
  label = 'Connect to GitHub',
  // children = label,
  // variant = 'outline',
  // size = 'lg',
  ...props
}: ConnectButtonProps) {
  return (
    <Button
      className={cn(
        'font-medium rounded-md transition-all duration-200',
        'bg-white text-foreground',
        'focus:ring-2 focus:ring-primary/25 focus:ring-offset-2',
        'border border-zinc-200',
        'py-2 px-4 h-10',
        'flex items-center justify-center gap-2'
        // className
      )}
      // variant={variant}
      // size={size}
      // leftIcon={icon}
      {...props}
    >
      {/* {children} */}
    </Button>
  )
}
