// 'use client'

// import { Button } from '@workspace/ui/components/button'
// import { useState } from 'react'
// import { useOnboarding } from '../store'

// type ConnectState = 'initial' | 'repository-select' | 'template-select'

// /**
//  * First step in the onboarding flow
//  * Handles GitHub connection and repository selection
//  *
//  * States:
//  * - initial: Shows GitHub connect button
//  * - repository-select: Shows list of repositories
//  * - template-select: Shows available templates
//  *
//  * @component
//  */
// export function ConnectStep() {
//   const [connectState, setConnectState] = useState<ConnectState>('initial')
//   const [projectName, setProjectName] = useState('')
//   const { setFormData, nextStep } = useOnboarding()

//   const handleConnect = () => {
//     setConnectState('repository-select')
//   }

//   return (
//     <div className="max-w-2xl w-full">
//       {/* <ConnectAccountTabPanel />\ */}
//       {connectState === 'initial' ? (
//         <div className="flex flex-col items-center justify-center gap-6 p-8">
//           <h2 className="text-2xl font-semibold text-center">
//             Connect to GitHub
//           </h2>
//           <p className="text-center text-muted-foreground">
//             Connect your GitHub account to get started
//           </p>
//           <Button onClick={handleConnect} />
//         </div>
//       ) : (
//         // <ConnectAccount onAuth={() => {}} />
//         <>...connect goes here</>
//       )}
//     </div>
//   )
// }

'use client'
// src/components/onboarding/connect-step/connect-step.tsx
import { useState } from 'react'
import { useRepoData } from '@/hooks/useRepoData'
import { useOnboarding } from '@/components/onboarding/useOnboarding'
import { ScrollableRepoList } from '@/components/onboarding/connect-step/repository-list'
import { TemplateList } from '@/components/onboarding/connect-step/template-list'
import { StepHeader } from '@/components/onboarding/common/step-header'
import { Button } from '@workspace/ui/components/button'
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@workspace/ui/components/select'
import { GitBranch } from 'lucide-react'

export const ConnectStep = () => {
  const { setFormData, formData, nextStep } = useOnboarding()
  const [selectedRepo, setSelectedRepo] = useState<string>(formData.githubRepo || '')
  const [isImportMode, setIsImportMode] = useState(true)
  const { repoData: repositories, isLoading } = useRepoData('')
  
  // Handle repository selection
  const handleRepoSelect = (repo: string) => {
    setSelectedRepo(repo)
    setFormData({ githubRepo: repo })
  }
  
  // Handle mode toggle between import and template
  const toggleMode = (mode: 'import' | 'template') => {
    setIsImportMode(mode === 'import')
  }
  
  return (
    <div className="flex flex-col items-center justify-center w-full px-8">
      <div className="w-full max-w-md">
        {/* Connect icon */}
        <div className="flex justify-center mb-6">
          <div className="w-16 h-16 bg-blue-500 bg-opacity-10 rounded-full flex items-center justify-center">
            <GitBranch className="h-8 w-8 text-blue-500" />
          </div>
        </div>
        
        {/* Connect header */}
        <StepHeader
          title="Connect"
          description="Connect and import a GitHub repo or start from a template"
        />
        
        {/* Git account selector */}
        <Select defaultValue="git-account">
          <SelectTrigger className="mb-4 bg-zinc-900 border-zinc-800">
            <SelectValue placeholder="Select Git account" />
          </SelectTrigger>
          <SelectContent>
            <SelectItem value="git-account">git-account</SelectItem>
          </SelectContent>
        </Select>
        
        {/* Mode buttons */}
        <div className="flex mb-4 space-x-2">
          <Button
            variant={isImportMode ? "default" : "outline"}
            className={`flex-1 ${isImportMode ? 'bg-blue-600 hover:bg-blue-700' : 'bg-zinc-900 border-zinc-800 hover:bg-zinc-800'}`}
            onClick={() => toggleMode('import')}
          >
            Import a repository
          </Button>
          <Button
            variant={!isImportMode ? "default" : "outline"}
            className={`flex-1 ${!isImportMode ? 'bg-blue-600 hover:bg-blue-700' : 'bg-zinc-900 border-zinc-800 hover:bg-zinc-800'}`}
            onClick={() => toggleMode('template')}
          >
            Start with a template
          </Button>
        </div>
        
        {/* Repository list or template list */}
        {isImportMode ? (
          <ScrollableRepoList 
            repositories={repositories || []} 
            isLoading={isLoading} 
            onSelect={handleRepoSelect}
            selectedRepo={selectedRepo}
          />
        ) : (
          <TemplateList onSelect={() => {}} />
        )}
        
        {/* Navigation buttons */}
        <div className="flex justify-end space-x-2 mt-8">
          <Button 
            variant="ghost" 
            className="text-muted-foreground bg-zinc-900 border-zinc-800 hover:bg-zinc-800"
            disabled={true} // Disable previous on first step
          >
            Previous
          </Button>
          <Button 
            className="bg-blue-600 hover:bg-blue-700" 
            onClick={nextStep}
            disabled={!selectedRepo && isImportMode}
          >
            Next
          </Button>
        </div>
      </div>
    </div>
  )
}
