// import { Button } from '@workspace/ui/components/button'
// import { GithubIcon } from 'lucide-react'

// interface Repository {
//   name: string
//   updatedAt: string
// }

// interface RepositoryListProps {
//   repositories: Repository[]
//   onSelect: (repo: Repository) => void
// }

// interface RepoCardProps {
//   repo: Repository
//   onClick: () => void
// }

// function RepoCard({ repo, onClick }: RepoCardProps) {
//   return (
//     <Button
//       onClick={onClick}
//       variant="ghost"
//       className="w-full flex items-center gap-3 p-3 hover:bg-accent hover:text-accent-foreground text-left"
//       aria-label={`Select repository ${repo.name}`}
//     >
//       <GithubIcon className="h-4 w-4 text-muted-foreground" />

//       <span className="flex-1 text-sm">{repo.name}</span>
//       <span className="text-xs text-muted-foreground">{repo.updatedAt}</span>
//     </Button>
//   )
// }

// export function RepositoryList({
//   repositories,
//   onSelect
// }: RepositoryListProps) {
//   return (
//     <div className="space-y-2">
//       {repositories.map((repo) => (
//         <RepoCard key={repo.name} repo={repo} onClick={() => onSelect(repo)} />
//       ))}
//     </div>
//   )
// }

'use client'
import { Github } from 'lucide-react'

interface Repository {
  id: string | number;
  full_name: string;
  html_url?: string;
}

interface ScrollableRepoListProps {
  repositories: Repository[];
  isLoading: boolean;
  onSelect: (repoFullName: string) => void;
  selectedRepo: string;
}

export function ScrollableRepoList({
  repositories,
  isLoading,
  onSelect,
  selectedRepo
}: ScrollableRepoListProps) {
  // If there are no repositories or we're loading, show appropriate message
  if (isLoading) {
    return (
      <div className="border border-zinc-800 rounded-md bg-zinc-900 overflow-hidden">
        <div className="p-6 text-center text-zinc-400">
          <svg className="animate-spin h-5 w-5 text-zinc-400 mx-auto mb-2" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
            <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4"></circle>
            <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
          </svg>
          Loading repositories...
        </div>
      </div>
    );
  }

  if (!repositories || repositories.length === 0) {
    return (
      <div className="border border-zinc-800 rounded-md bg-zinc-900 overflow-hidden">
        <div className="p-6 text-center text-zinc-400">
          No repositories found. Make sure your GitHub account is connected.
        </div>
      </div>
    );
  }

  // Generate mock repositories if needed for testing
  const repoList = repositories.length > 0 ? repositories : 
    Array.from({ length: 15 }, (_, i) => ({
      id: `mock-${i}`,
      full_name: `git-account/repo-name-${i + 1}`
    }));

  return (
    <div className="border border-zinc-800 rounded-md bg-zinc-900 overflow-hidden">
      {/* Ensure we have a fixed height container with scrolling */}
      <div 
        className="max-h-60 overflow-y-auto"
        style={{ 
          scrollbarWidth: 'thin',
          scrollbarColor: '#4b5563 #1f2937'
        }}
      >
        {repoList.map((repo, index) => (
          <div 
            key={repo.id || index} 
            className={`flex items-center p-4 border-b border-zinc-800 last:border-b-0 cursor-pointer hover:bg-zinc-800 transition-colors duration-150 ${
              selectedRepo === repo.full_name ? 'bg-zinc-800' : ''
            }`}
            onClick={() => onSelect(repo.full_name)}
          >
            <div className="flex-1 text-white">
              <Github className="inline-block h-4 w-4 mr-2 text-zinc-400" />
              <span>{repo.full_name}</span>
            </div>
            <div className="text-sm text-zinc-400">
              5 minutes ago
            </div>
          </div>
        ))}
      </div>
    </div>
  );
}