// import { Button } from '@workspace/ui/components/button'
// import { Input } from '@workspace/ui/components/input'
// import type React from 'react'
// interface Template {
//   id: string
//   name: string
//   description: string
//   icon: React.ReactNode
// }

// interface TemplateListProps {
//   templates: Template[]
//   onSelect: (template: Template) => void
//   projectName: string
//   onProjectNameChange: (name: string) => void
// }

// export function TemplateList({
//   templates,
//   onSelect,
//   projectName,
//   onProjectNameChange
// }: TemplateListProps) {
//   return (
//     <div className="space-y-6">
//       <div className="space-y-2">
//         <label
//           htmlFor="project-name"
//           className="text-sm font-medium text-foreground"
//         >
//           Project Name
//         </label>
//         <Input
//           id="project-name"
//           value={projectName}
//           onChange={(e) => onProjectNameChange(e.target.value)}
//           placeholder="new-repository-name"
//           className="bg-background"
//         />
//       </div>
//       <div className="space-y-2">
//         {templates.map((template) => (
//           <Button
//             key={template.id}
//             onClick={() => onSelect(template)}
//             className="w-full flex items-center gap-3 p-3 rounded-lg hover:bg-accent hover:text-accent-foreground transition-colors text-left"
//           >
//             <div className="h-8 w-8 rounded bg-muted flex items-center justify-center">
//               {template.icon}
//             </div>
//             <div>
//               <div className="text-sm font-medium">{template.name}</div>
//               <div className="text-xs text-muted-foreground">
//                 {template.description}
//               </div>
//             </div>
//           </Button>
//         ))}
//       </div>
//     </div>
//   )
// }

'use client'
// src/components/onboarding/connect-step/template-list.tsx
import { Box, Layout } from 'lucide-react'

interface Template {
  id: string;
  name: string;
  description: string;
  icon: React.ReactNode;
}

interface TemplateListProps {
  onSelect: (templateId: string) => void;
  selectedTemplate?: string;
}

export const TemplateList = ({ onSelect, selectedTemplate }: TemplateListProps) => {
  // Mock templates data - in a real app, this would come from an API
  const templates: Template[] = [
    {
      id: 'next-js',
      name: 'Next.js',
      description: 'React framework with hybrid static & server rendering',
      icon: <Layout className="h-6 w-6" />
    },
    {
      id: 'react-app',
      name: 'React App',
      description: 'Modern React application with Vite',
      icon: <Box className="h-6 w-6" />
    },
    {
      id: 'static-site',
      name: 'Static Site',
      description: 'Simple static site with HTML, CSS, and JavaScript',
      icon: <Layout className="h-6 w-6" />
    }
  ];

  return (
    <div className="border border-zinc-800 rounded-md bg-zinc-900 overflow-hidden">
      <div className="max-h-60 overflow-y-auto">
        {templates.map((template) => (
          <div
            key={template.id}
            className={`flex items-center p-4 border-b border-zinc-800 last:border-b-0 cursor-pointer hover:bg-zinc-800 ${
              selectedTemplate === template.id ? 'bg-zinc-800' : ''
            }`}
            onClick={() => onSelect(template.id)}
          >
            <div className="mr-3 p-2 bg-zinc-800 rounded-md">
              {template.icon}
            </div>
            <div className="flex-1">
              <div className="font-medium text-sm">{template.name}</div>
              <div className="text-xs text-muted-foreground">{template.description}</div>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
};