/**
 * Onboarding Flow
 *
 * This module exports all components related to the onboarding flow.
 * The onboarding process guides users through connecting their GitHub repository,
 * configuring their deployment settings, and deploying their application.
 *
 * @see https://www.figma.com/design/cfMOy1RJasIu3QyzAMBFxB/Laconic?node-id=571-3500&m=dev
 */

// Main component
export { default as Onboarding } from './Onboarding'
export {
  default as OnboardingDialog,
  hasCompletedOnboarding
} from './OnboardingDialog'

// Step components
export { ConfigureStep } from './configure-step'
export { ConnectStep } from './connect-step'
export { DeployStep } from './deploy-step'
export { OnboardingSidebar } from './OnboardingSidebar'
export { SuccessStep } from './success-step/success-step'
// Common components
export * from './common'

// Sidebar components
export * from './sidebar'

// Store and hooks
export { useOnboarding } from './store'

// Types
export * from './types'
