import { cn } from '@/lib/utils'
import type { OmitCommon } from '@/types/common'
import { getInitials } from '@/utils/getInitials'
import type { Project } from '@workspace/gql-client'
import {
  Avatar,
  AvatarFallback,
  AvatarImage
} from '@workspace/ui/components/avatar'
import type { Overwrite, UseComboboxGetItemPropsReturnValue } from 'downshift'
import { type ComponentPropsWithoutRef, forwardRef } from 'react'

/**
 * Represents a type that merges ComponentPropsWithoutRef<'li'> with certain exclusions.
 * @type {MergedComponentPropsWithoutRef}
 */
type MergedComponentPropsWithoutRef = OmitCommon<
  ComponentPropsWithoutRef<'button'>,
  Omit<
    Overwrite<UseComboboxGetItemPropsReturnValue, Project[]>,
    'index' | 'item'
  >
>

interface ProjectSearchBarItemProps extends MergedComponentPropsWithoutRef {
  item: Project
  active?: boolean
}

const ProjectSearchBarItem = forwardRef<
  HTMLButtonElement,
  ProjectSearchBarItemProps
>(({ item, active, ...props }, ref) => {
  return (
    <button
      {...props}
      ref={ref}
      key={item.id}
      className={cn(
        'px-2 py-2 flex items-center gap-3 rounded-lg text-left hover:bg-base-bg-emphasized',
        {
          'bg-base-bg-emphasized': active
        }
      )}
    >
      <Avatar>
        <AvatarImage src={item.icon} />
        <AvatarFallback>{getInitials(item.name)}</AvatarFallback>
      </Avatar>
      <div className="flex flex-col flex-1">
        <p className="text-sm tracking-[-0.006em] text-elements-high-em">
          {item.name}
        </p>
        <p className="text-xs text-elements-low-em">{item.organization.name}</p>
      </div>
    </button>
  )
})

ProjectSearchBarItem.displayName = 'ProjectSearchBarItem'

export { ProjectSearchBarItem }
