import { Input } from '@workspace/ui/components/input'
import { Calendar, ChevronDown, Search } from 'lucide-react'
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from '@workspace/ui/components/dropdown-menu'
import { useState } from 'react'

export enum StatusOptions {
  ALL_STATUS = 'All Status',
  BUILDING = 'Building',
  READY = 'Ready',
  ERROR = 'Error',
  DELETING = 'Deleting'
}

export interface FilterValue {
  searchedBranch: string
  status: StatusOptions
  dateRange?: string
}

interface FilterFormProps {
  value?: FilterValue
  onChange?: (value: FilterValue) => void
}

export function FilterForm({ value, onChange }: FilterFormProps) {
  const defaultValue: FilterValue = {
    searchedBranch: '',
    status: StatusOptions.ALL_STATUS,
    dateRange: 'Jan 20, 2023 - Feb 09, 2023'
  };

  // Initialize with props or default values
  const [filterValue, setFilterValue] = useState<FilterValue>(value || defaultValue);

  // Handle changes locally and propagate to parent
  const handleChange = (newValue: Partial<FilterValue>) => {
    const updatedValue = { ...filterValue, ...newValue };
    setFilterValue(updatedValue);
    onChange?.(updatedValue);
  };

  return (
    <div className="flex items-center gap-4 mb-6">
      {/* Search Input */}
      <div className="relative flex-1">
        <Search className="absolute left-3 top-1/2 -translate-y-1/2 text-gray-400 w-4 h-4" />
        <Input
          type="text"
          placeholder="Search branches"
          className="pl-9 bg-transparent border-gray-700 rounded-lg"
          value={filterValue.searchedBranch}
          onChange={(e) => handleChange({ searchedBranch: e.target.value })}
        />
      </div>

      {/* Date Range Button */}
      <div className="relative">
        <button className="flex items-center gap-2 px-4 py-2.5 border border-gray-700 rounded-lg text-sm">
          <Calendar className="w-4 h-4 text-gray-400" />
          <span>{filterValue.dateRange}</span>
        </button>
      </div>

      {/* Status Dropdown */}
      <DropdownMenu>
        <DropdownMenuTrigger asChild>
          <button className="flex items-center gap-2 px-4 py-2.5 border border-gray-700 rounded-lg text-sm">
            <span>{filterValue.status}</span>
            <ChevronDown className="w-4 h-4 ml-1 text-gray-400" />
          </button>
        </DropdownMenuTrigger>
        <DropdownMenuContent>
          <DropdownMenuItem onClick={() => handleChange({ status: StatusOptions.ALL_STATUS })}>
            All Status
          </DropdownMenuItem>
          <DropdownMenuItem onClick={() => handleChange({ status: StatusOptions.BUILDING })}>
            Building
          </DropdownMenuItem>
          <DropdownMenuItem onClick={() => handleChange({ status: StatusOptions.READY })}>
            Ready
          </DropdownMenuItem>
          <DropdownMenuItem onClick={() => handleChange({ status: StatusOptions.ERROR })}>
            Error
          </DropdownMenuItem>
          <DropdownMenuItem onClick={() => handleChange({ status: StatusOptions.DELETING })}>
            Deleting
          </DropdownMenuItem>
        </DropdownMenuContent>
      </DropdownMenu>
    </div>
  )
}