// src/context/WalletContext.tsx
'use client'

import { createContext, useContext } from 'react'

/**
 * Wallet Context Interface
 */
export interface WalletContextType {
  // Wallet state
  wallet: {
    id: string
    address: string
  } | null
  
  // Connection states
  isConnected: boolean        // SIWE authenticated + backend session
  hasWalletAddress: boolean   // Just has wallet address
  isLoading: boolean          // Connection/auth in progress
  
  // Actions
  connect: () => Promise<void>
  disconnect: () => void
  checkSession: () => Promise<boolean>
  
  // Debug info
  lastError?: string
}

/**
 * Wallet Context
 */
export const WalletContext = createContext<WalletContextType | undefined>(undefined)

/**
 * useWallet Hook
 * @description Hook to access wallet context. Must be used within WalletProvider.
 * @throws Error if used outside WalletProvider
 */
export const useWallet = (): WalletContextType => {
  const context = useContext(WalletContext)
  if (context === undefined) {
    throw new Error('useWallet must be used within a WalletProvider')
  }
  return context
}