import type { LucideIcon } from 'lucide-react'
import type { ReactNode } from 'react'

// Base navigation item type
export interface NavItem {
  title: string
  href: string
  icon?: LucideIcon
  isExternal?: boolean
}

// Search result item
export interface SearchResultItem {
  id: string
  title: string
  description?: string
  href: string
  icon?: LucideIcon
  category?: string
}

// Configuration for breadcrumbs
export interface BreadcrumbsConfig {
  homeLabel?: string
  homeHref?: string
  pathMap?: Record<string, string>
}

// Configuration for search component
export interface SearchConfig {
  placeholder?: string
  onSearch?: (query: string) => void
  showMobile?: boolean
  searchResults?: SearchResultItem[]
  onSelectItem?: (item: SearchResultItem) => void
  categories?: string[]
}

// Configuration for user navigation
export interface UserNavConfig {
  avatarSrc?: string
  username?: string
  email?: string
  showMobile?: boolean
}

// Configuration for the header
export interface HeaderConfig {
  logo?: ReactNode
  logoMobile?: ReactNode
  navItems: NavItem[]
  searchConfig?: SearchConfig
  userConfig?: UserNavConfig
}

// Configuration for the page header
export interface PageHeaderConfig {
  breadcrumbsConfig?: BreadcrumbsConfig
}

// Configuration for the dashboard layout
export interface DashboardLayoutConfig {
  headerConfig: HeaderConfig
  pageHeaderConfig?: PageHeaderConfig
}
