# deployer

- Install dependencies

  ```bash
  pnpm install
  ```

  ```bash
  # if you do not have jq installed already
  brew install jq
  # OR
  sudo apt-get install jq
  ```

- Copy and update `.env`

  ```
  cp .env.example .env
  ```

  Set the required variables:

  ```
  REGISTRY_BOND_ID=<bond-id>
  DEPLOYER_LRN=lrn://vaasl-provider/deployers/webapp-deployer-api.apps.vaasl.io
  AUTHORITY=vaasl
  ```

  Note: The bond id should be set to the `vaasl` authority

- Set the `userKey` and `bondId` in [config.yml](./config.yml)

  Note: The `bondId` should be created by the `userKey` account

- Set the actual values for env in [deploy-frontend.sh](./deploy-frontend.sh) for the following:
  ```sh
  NEXT_PUBLIC_CLERK_PUBLISHABLE_KEY=your_clerk_key
  CLERK_SECRET_KEY=your_clerk_secret
  NEXT_PUBLIC_GITHUB_FALLBACK_TOKEN=your_github_token
  ```

- Run script to deploy app to `deploy.laconic.com`

  ```bash
  ./deploy-frontend.sh
  ```

- Commit the updated [ApplicationRecord](records/application-record.yml) and [ApplicationDeploymentRequest](records/application-deployment-request.yml) files to the repository

## Notes

- Any config env can be updated in [records/application-deployment-request.yml](records/application-deployment-request.yml)

  ```yml
  record:
    ...
    config:
      env:
        LACONIC_HOSTED_CONFIG_app_server_url: https://snowballtools-base-api-001.apps.snowballtools.com
        ...
  ```

  - On changing `LACONIC_HOSTED_CONFIG_app_github_clientid`, the GitHub client ID and secret need to be changed in backend config too

## Troubleshoot

- Check deployment status in [web-app deployer](https://console.laconic.com/deployer).
- Check records in [registry console app](https://console.laconic.com/#/registry).

- If deployment fails due to low bond balance
  - Check balances

    ```bash
    # Account balance
    pnpm laconic registry account get

    # Bond balance
    pnpm laconic registry bond get --id 99c0e9aec0ac1b8187faa579be3b54f93fafb6060ac1fd29170b860df605be32
    ```

  - Command to refill bond

    ```bash
    pnpm laconic registry bond refill --id 99c0e9aec0ac1b8187faa579be3b54f93fafb6060ac1fd29170b860df605be32 --type alnt --quantity 10000000
    ```
